# Installing the required packages for this analysis. 
# This is only required once. 
# Uncomment the code below to run the install.packages function.
# install.packages(c("eRm", "dplyr", "ggplot2", "pairwise", "TAM", "psych"))

# Load the packages required for the analysis
library(eRm)
library(dplyr)
library(TAM)
library(psych)


# Reading in the comma-seperated data set
df <- read.csv("ARMChapter6.csv", header = TRUE, sep = ";") 

# Select the 12 columns of df where the IASQ items are at
iasq_items <- df[,2:13]
# Looking at the first five rows of the IASQ dataframe
head(iasq_items)
# Look at the category distribution across the items
sapply(iasq_items, table)

# Fit the RSM using eRm. This will likely not work!
erm_rsm <- RSM(iasq_items)

erm_rsm

# Fit a Rating Scale model for the IASQ
fit_RSM <- tam.mml(resp = iasq_items-1, 
                        irtmodel = "RSM") 



# Extract IRT parameters from the fit_RSM object.
rsm_par<-fit_RSM[["item_irt"]] 
rsm_par

# See item thresholds
item_thresh<-tam.threshold(fit_RSM)
item_thresh

# The distance between the thresholds is the same for all items
item_thresh[,2] - item_thresh[,1]


 # Item fit
msq.itemfit(fit_RSM)

# Use the "psych" package to get corrected item-total correlations:
iasq_rel <- psych::alpha(iasq_items) 
# check column "r.drop" for the correlation of item responses with the scale composed of the remaining items. 
iasq_rel[["item.stats"]]


# Calculate item locations
(item_thresh <- IRT.threshold(fit_RSM, type = "item")) 
# Plot the item locations Wright Map
IRT.WrightMap(item_thresh, type = "item")

# Wright map with category thresholds
IRT.WrightMap(fit_RSM)



# Remove item 12 which is in the 12th column
iasq_items_2 <- iasq_items[,-12]

# Look at the data
head(iasq_items_2)

# Fit the new model
fit_RSM_no_12 <- tam.mml(resp = iasq_items_2-1, 
                        irtmodel = "RSM") 

# New thresholds
item_thresh_2<-tam.threshold(fit_RSM_no_12)
item_thresh_2

# Item fit
msq.itemfit(fit_RSM_no_12)

